summaryrefslogtreecommitdiff
path: root/converter/m0110_usb/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'converter/m0110_usb/config.h')
-rw-r--r--converter/m0110_usb/config.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/converter/m0110_usb/config.h b/converter/m0110_usb/config.h
index d2e904077..b1b971ec9 100644
--- a/converter/m0110_usb/config.h
+++ b/converter/m0110_usb/config.h
@@ -36,9 +36,10 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
/* Locking Caps Lock support */
//#define MATRIX_HAS_LOCKING_CAPS
/* key combination for command */
#define IS_COMMAND() ( \
- keyboard_report->mods == (MOD_BIT(KC_LALT) | MOD_BIT(KC_LGUI)) \
+ matrix_is_on((BACKSPACE_CODE>>3)&0x0F, BACKSPACE_CODE&0x07) \
)
@@ -36,9 +36,10 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
/* Locking Caps Lock support */
//#define MATRIX_HAS_LOCKING_CAPS
-/* key combination for command */
+/* Backspace for command key */
+#define BACKSPACE_CODE 0x33
#define IS_COMMAND() ( \